using System;
using System.Linq;
using System.Threading.Tasks;
using Windows.ApplicationModel.Activation;
using Windows.ApplicationModel.DataTransfer;
using Windows.Storage.Pickers.Provider;
using Windows.Storage.Streams;
using Windows.UI.Xaml;
using Windows.UI.Xaml.Media.Imaging;

namespace MetroDemo
{
	partial class App
	{
		public App()
		{
			InitializeComponent();
		}

		protected override void OnLaunched(LaunchActivatedEventArgs args)
		{
			Window.Current.Content = new MainPage();
			Window.Current.Activate();
		}

		/// <summary>
		/// This function opens a new page to display all the images associated with the provided keyword
		/// </summary>
		public static void ShowImagesPage(string keyword)
		{
			Window.Current.Content = new ImagesPage { Keyword = keyword };
		}

		/// <summary>
		/// Handles Sharing Contract activation
		/// </summary>
		protected override void OnSharingTargetActivated(ShareTargetActivatedEventArgs args)
		{
			if (args.ShareOperation.Data.AvailableFormats.Contains(StandardDataFormats.Bitmap))
			{
				IRandomAccessStream imageReceived = args.ShareOperation.Data.GetBitmap();
				BitmapImage bitmapImage = new BitmapImage();
				bitmapImage.SetSource(imageReceived);

				var page = new OneImagePage();
				page.Activate(bitmapImage);
			}

		}

		/// <summary>
		/// This busket will be used on ImagesPage to return the selected files via FilePicker Contract
		/// </summary>
		public static FilePickerBasket Basket { get; set; }

		/// <summary>
		/// Handles File Picker Contract activation
		/// </summary>
		protected override void OnFilePickerActivated(FilePickerActivatedEventArgs args)
		{
			Basket = args.Basket;

			Window.Current.Content = new MainPage();
			Window.Current.Activate();
		}

		/// <summary>
		/// Handles Search Contract activation
		/// </summary>
		protected override void OnSearchActivated(SearchActivatedEventArgs args)
		{
			ShowImagesPage(args.QueryText);
			Window.Current.Activate();
		}

	}
}
