﻿using System;
using System.Collections.Generic;
using System.Collections.ObjectModel;
using System.Linq;
using System.Threading.Tasks;
using MetroDemo.Model;
using Windows.ApplicationModel.DataTransfer;
using Windows.Foundation;
using Windows.Storage;
using Windows.Storage.Streams;
using Windows.UI.Xaml;
using Windows.UI.Xaml.Controls;
using Windows.UI.Xaml.Data;

namespace MetroDemo
{
	public sealed partial class ImagesPage
	{
		private bool _isLoaded;
		public string Keyword { get; set; }

		StorageFile _lastSelectedFile;
		IRandomAccessStream _fileStream;

		public ImagesPage()
		{
			InitializeComponent();
			Loaded += ImagesPage_Loaded;

			SetupSharing();
		}

		private void SetupSharing()
		{
			var dataTransferManager = DataTransferManager.GetForCurrentView();
			if (dataTransferManager != null)
				dataTransferManager.DataRequested += dataTransferManager_DataRequested;
		}

		void dataTransferManager_DataRequested(DataTransferManager sender, DataRequestedEventArgs args)
		{
			if (_lastSelectedFile == null)
				return;

			args.Request.Data.Properties.Title = "Metro Demo";
			args.Request.Data.Properties.Description = "Selected Image";
			args.Request.Data.SetBitmap(_fileStream);
		}

		async void ImagesPage_Loaded(object sender, RoutedEventArgs e)
		{
			if (_isLoaded)
				return;

			_isLoaded = true;

			var imagesVector = new ObservableCollection<object>().ToObservableVector<object>();
			ImagesViewSource.Source = imagesVector;

			await ImageModel.PopulateImages(Keyword, imagesVector);
		}

		private void BackButton_Click(object sender, RoutedEventArgs e)
		{
			Window.Current.Content = new MainPage();
			Window.Current.Activate();
		}

		async private void GridViewControl_SelectionChanged(object sender, SelectionChangedEventArgs e)
		{
			var data = e.AddedItems.FirstOrDefault() as ImageModel;
			if (data != null)
			{
				_lastSelectedFile = await StorageFile.GetFileFromPathAsync(data.Path);
				_fileStream = await _lastSelectedFile.OpenAsync(FileAccessMode.Read);
			}

			if (App.Basket != null)
			{
				App.Basket.AddFile("image_id", _lastSelectedFile);
			}
		}

	}
}
