﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using Windows.Storage;
using Windows.Storage.FileProperties;
using Windows.Storage.Search;
using Windows.UI.Xaml.Media.Imaging;

namespace MetroDemo.Model
{
	/// <summary>
	/// Contains information about images do display
	/// </summary>
	public class ImageModel
	{
		public BitmapImage Image { get; set; }
		public string Path { get; set; }

		/// <summary>
		/// Scans Picture Library and extracts all the keywords 
		/// from the files located in the folder and all the subfolders
		/// </summary>
		/// <param name="keywordsVector">The method populates keywordsVector with the found keywords</param>
		async public static Task PopulateKeywords(ObservableVector<object> keywordsVector)
		{
			keywordsVector.Clear();

			var files = await KnownFolders.PicturesLibrary.GetFilesAsync(CommonFileQuery.OrderByName);
			foreach (StorageFile file in files)
			{
				var imageProperties = await file.Properties.GetImagePropertiesAsync();

				if (imageProperties.Keywords != null)
				{
					foreach (var keyword in imageProperties.Keywords.ToList())
					{
						if (!keywordsVector.Contains(keyword))
						{
							keywordsVector.Add(keyword);
						}
					}
				}
			}
		}

		/// <summary>
		/// Searches Pictures Library for the images tagged with the keyword
		/// </summary>
		/// <param name="keyword">Keyword to search</param>
		/// <param name="imagesVector">Found images</param>
		async public static Task PopulateImages(string keyword, ObservableVector<object> imagesVector)
		{
			imagesVector.Clear();

			var queryOptions = new QueryOptions { FolderDepth = FolderDepth.Deep };
			queryOptions.FileTypeFilter.Add("*");
			queryOptions.ApplicationSearchFilter = "tags:" + keyword;

			StorageFileQueryResult query = KnownFolders.PicturesLibrary.CreateFileQueryWithOptions(queryOptions);

			IReadOnlyList<IStorageFile> files = await query.GetFilesAsync();
			foreach (StorageFile file in files)
			{
				var image = await file.GetThumbnailAsync(ThumbnailMode.PicturesView, 200);
				if (image != null)
				{
					BitmapImage bitmapImage = new BitmapImage();
					bitmapImage.SetSource(image);

					imagesVector.Add(new ImageModel { Image = bitmapImage, Path = file.Path });
				}
			}
		}

	}
}
